"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = void 0;
const core_1 = require("@serverless-cd/core");
const child_process_1 = require("child_process");
const setup_1 = __importDefault(require("./setup"));
function getCredential(inputs, context) {
    return __awaiter(this, void 0, void 0, function* () {
        const credentials = {
            accountId: core_1.lodash.get(context, 'inputs.sts.accountId') || core_1.lodash.get(context, 'inputs.uid'),
            accessKeyId: core_1.lodash.get(context, 'inputs.sts.accessKeyId'),
            accessKeySecret: core_1.lodash.get(context, 'inputs.sts.accessKeySecret'),
            securityToken: core_1.lodash.get(context, 'inputs.sts.securityToken'),
        };
        if (credentials.accountId && credentials.accessKeyId && credentials.accessKeySecret) {
            return credentials;
        }
        return yield (0, core_1.getCredentials)(inputs, context);
    });
}
const getPluginInputs = (inputs, context, logger) => __awaiter(void 0, void 0, void 0, function* () {
    logger.debug(`context: ${JSON.stringify(context)}`);
    logger.debug(`original inputs: ${JSON.stringify(inputs)}`);
    const newInputs = core_1.lodash.assign((0, core_1.getInputs)(inputs, context), {
        projectName: core_1.lodash.get(context, 'inputs.context.data.projectName'),
        envName: core_1.lodash.get(context, 'inputs.context.data.envName'),
        infraStackName: core_1.lodash.get(context, 'inputs.context.data.infraStackName')
    });
    logger.debug(`merged inputs: ${JSON.stringify(newInputs)}`);
    const credentials = yield getCredential(newInputs, context);
    return {
        alias: core_1.lodash.get(inputs, 'alias', 'default'),
        credentials,
        projectName: core_1.lodash.get(newInputs, 'projectName'),
        envName: core_1.lodash.get(newInputs, 'envName'),
        infraStackName: core_1.lodash.get(newInputs, 'infraStackName'),
        workspace: core_1.lodash.get(context, 'cwd'),
    };
});
const run = (inputs, context, logger) => __awaiter(void 0, void 0, void 0, function* () {
    logger.info('start @serverless-cd/s-setup run');
    const props = yield getPluginInputs(inputs, context, logger);
    const cwd = core_1.lodash.get(context, 'cwd', '');
    const lsRes = (0, child_process_1.spawnSync)(`ls -al ${cwd}`, { shell: true, encoding: 'utf8' });
    logger.debug(`ls -al ${cwd} res: ${lsRes.stdout}`);
    yield (0, setup_1.default)(props, logger);
    logger.info('Run @serverless-cd/s-setup end');
});
exports.run = run;
exports.default = setup_1.default;
//# sourceMappingURL=index.js.map