"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@serverless-cd/core");
const child_process_1 = require("child_process");
function setup(props, logger) {
    try {
        checkDevs(logger);
    }
    catch (_e) {
        logger.info('Attempt to install devs...');
        (0, child_process_1.spawnSync)('npm install @serverless-devs/s -g', { shell: true, encoding: 'utf8' });
        logger.info('Attempt to install devs end. Retry check s');
        checkDevs(logger);
    }
    initAccess(props, logger);
    initEnvironment(props, logger);
    setDefaultEnvironment(props, logger);
}
exports.default = setup;
function checkDevs(logger) {
    const { status, stdout, stderr } = (0, child_process_1.spawnSync)('s --version', { shell: true, encoding: 'utf8' });
    logger.debug(`Run s --version status: ${status}`);
    logger.info(stdout);
    if (stderr) {
        logger.error(stderr);
    }
    if (status !== 0) {
        throw new Error('Serverless Devs is not installed');
    }
}
const initAccess = (props, logger) => {
    const alias = core_1.lodash.get(props, 'alias', 'default');
    const credentials = core_1.lodash.get(props, 'credentials', {});
    if (core_1.lodash.isEmpty(credentials)) {
        throw new Error('Failed to setup Serverless Devs');
    }
    let runCommond = `s config add --AccessKeyID "${credentials.accessKeyId}" --AccessKeySecret "${credentials.accessKeySecret}"`;
    if (credentials.accountId) {
        runCommond = `${runCommond} --AccountID ${credentials.accountId}`;
    }
    if (credentials.securityToken) {
        runCommond = `${runCommond} --SecurityToken "${credentials.securityToken}"`;
    }
    runCommond = `${runCommond} --access "${alias}" -f`;
    logger.debug(`Run s add commond: ${runCommond}`);
    const addRes = (0, child_process_1.spawnSync)(runCommond, { shell: true, encoding: 'utf8' });
    logger.info(addRes.stdout);
    if (addRes.stderr) {
        logger.error(addRes.stderr);
    }
    process.env.serverless_devs_access_cicd_alias_name = alias;
};
const initEnvironment = (props, logger) => {
    const { workspace, envName, infraStackName } = props;
    const alias = core_1.lodash.get(props, 'alias', 'default');
    if (!envName) {
        return;
    }
    let cmd = `s env init --name ${envName} --access ${alias}`;
    if (infraStackName) {
        cmd += ` --infra-stack-name ${infraStackName}`;
    }
    logger.info(`Execute command: ${cmd} \n\n`);
    const result = (0, child_process_1.spawnSync)(cmd, { cwd: workspace, shell: true, encoding: 'utf8' });
    logger.info(result.stdout);
    if (result.stderr) {
        logger.error(result.stderr);
    }
    if (result.status !== 0) {
        throw new Error('Failed to init environment');
    }
};
const setDefaultEnvironment = (props, logger) => {
    const { workspace, envName } = props;
    if (!envName) {
        return;
    }
    const cmd = `s env default --name ${envName}`;
    logger.info(`Execute command: ${cmd} \n\n`);
    const result = (0, child_process_1.spawnSync)(cmd, { cwd: workspace, shell: true, encoding: 'utf8' });
    logger.info(result.stdout);
    if (result.stderr) {
        logger.error(result.stderr);
    }
    if (result.status !== 0) {
        throw new Error('Failed to set default environment');
    }
};
//# sourceMappingURL=setup.js.map